@@ -46,7 +46,7 @@ class CallNotify(hildondesktop.StatusMenuItem):
 		#atexit.register(self.cleanup)
 		
 		# add GUI buttons
-		self.addGUI()
+		# self.addGUI()
 		self.dbg('constructor end')
 	
     def addGUI(self):
@@ -339,9 +339,11 @@ class CallNotify(hildondesktop.StatusMenuItem):
     def show(self):
 		self.dbg('show started')
 		# blink the icon every 1 second
-		if not(self.stop) and self.visual:
+		if not(self.stop):
+			self.readConfigurationFile()
 			self.stop = True
-			self.tmr_ptr = gobject.timeout_add(1000, self.blinkIcon)
+			if self.visual:
+				self.tmr_ptr = gobject.timeout_add(1000, self.blinkIcon)
 			self.tmr_ptr2 = gobject.timeout_add(int(self.interval*1000*60), self.playSound)
 			
     def blinkIcon(self):
